@@ -1,7 +1,7 @@
 compare_vector <- function(x, y, paths = c("x", "y"), opts = compare_opts()) {
 
   # Early exit for numerics (except for) with format methods
-  if (typeof(x) %in% c("integer", "double") && num_equal(x, y, opts$tolerance)) {
+  if (is_numeric(x) && num_equal(x, y, opts$tolerance)) {
     return()
   }
 
@@ -18,14 +18,17 @@ compare_vector <- function(x, y, paths = c("x", "y"), opts = compare_opts()) {
   if (length(out) == 0) {
     out <- c(out, switch(typeof(x),
       integer = ,
-      complex = ,
       double = compare_numeric(x, y, paths,
         tolerance = opts$tolerance,
         max_diffs = opts$max_diffs
       ),
+      complex = compare_complex(x, y, paths,
+        tolerance = opts$tolerance,
+        max_diffs = opts$max_diffs
+      ),
       logical = compare_logical(x, y, paths, max_diffs = opts$max_diffs),
       raw = ,
-      character = compare_character(x, y, paths, max_diffs = opts$max_diffs)
+      character = compare_character(x, y, paths, quote = if (opts$quote_strings) '"' else NULL, max_diffs = opts$max_diffs)
     ))
   }
   out
@@ -61,7 +64,14 @@ compare_character <- function(x, y, paths = c("x", "y"), quote = "\"", max_diffs
       new_compare(compare_by_line(x, y, paths, opts))
     }
   } else {
-    diff_element(x, y, paths, quote = quote, max_diffs = max_diffs)
+    diff_element(
+      x,
+      y,
+      paths,
+      quote = quote,
+      max_diffs = max_diffs,
+      is_string = TRUE
+    )
   }
 }
 
@@ -70,7 +80,7 @@ compare_numeric <- function(x, y, paths = c("x", "y"), tolerance = default_tol()
     return(new_compare())
   }
 
-  if (!is.null(dim(x)) && identical(dim(x), dim(y))) {
+  if (length(dim(x)) == 2 && identical(dim(x), dim(y))) {
     rows <- printed_rows(x, y, paths = paths)
     out <- diff_rows(rows, paths = paths, max_diffs = max_diffs)
 
@@ -80,7 +90,7 @@ compare_numeric <- function(x, y, paths = c("x", "y"), tolerance = default_tol()
   }
 
   if (length(x) == length(y)) {
-    digits <- min_digits(x, y)
+    digits <- min_digits(x, y, tolerance)
     x_fmt <- num_exact(x, digits = digits)
     y_fmt <- num_exact(y, digits = digits)
   } else {
@@ -103,6 +113,38 @@ compare_numeric <- function(x, y, paths = c("x", "y"), tolerance = default_tol()
   }
 }
 
+compare_complex <- function(x, y, paths = c("x", "y"), tolerance = default_tol(), max_diffs = Inf) {
+
+  if (length(x) == length(y)) {
+    c(
+      compare_numeric(
+        Re(x),
+        Re(y),
+        paths = paste0("Re(", paths, ")"),
+        tolerance = tolerance,
+        max_diffs = max_diffs
+      ),
+      compare_numeric(
+        Im(x),
+        Im(y),
+        paths = paste0("Im(", paths, ")"),
+        tolerance = tolerance,
+        max_diffs = max_diffs
+      )
+    )
+  } else {
+    x_fmt <- format(x)
+    y_fmt <- format(y)
+
+    diff_element(
+      x_fmt, y_fmt, paths,
+      quote = NULL,
+      justify = "right",
+      max_diffs = max_diffs
+    )
+  }
+}
+
 # Helpers -----------------------------------------------------------------
 
 num_exact <- function(x, digits = 6) {
@@ -110,11 +152,20 @@ num_exact <- function(x, digits = 6) {
 }
 
 # Minimal number of digits needed to show differences
-min_digits <- function(x, y) {
+min_digits <- function(x, y, tolerance = default_tol()) {
+  if (is.integer(x) && is.integer(y)) {
+    return(0L)
+  }
+
   attributes(x) <- NULL
   attributes(y) <- NULL
 
-  digits(abs(x - y))
+  n <- digits(abs(x - y))
+  if (!is.null(tolerance)) {
+    n <- min(n, digits(tolerance))
+  }
+
+  as.integer(n) + 1L
 }
 
 # This looks ok:
