@@ -36,3 +36,14 @@ test_that("NaN is equal to NA_real_ unless tolerance is NULL", {
   expect_true(num_equal(NaN, NaN))
   expect_true(num_equal(NA_real_, NA_real_))
 })
+
+test_that("can't can't compare large integers", {
+  expect_snapshot(
+    num_equal(9007199254740995, bit64::as.integer64(1)),
+    error = TRUE
+  )
+  expect_false(num_equal(9007199254740991, bit64::as.integer64(1)))
+
+  expect_no_error(num_equal(NA, bit64::as.integer64(1)))
+  expect_no_error(num_equal(bit64::as.integer64(1), NA))
+})
