@@ -1,3 +1,10 @@
+test_that("as_map() keeps attributes", {
+  expect_equal(
+    as_map(structure(list(b = 1, a = 2), attr1 = "a")),
+    structure(list(a = 2, b = 1), attr1 = "a")
+  )
+})
+
 test_that("as_map() leaves unnnamed components alone", {
   expect_equal(as_map(c(c = 5, 2, b = 3, 4, a = 1)), c(a = 1, 2, b = 3, 4, c = 5))
   expect_equal(as_map(c(c = 3, b = 2, a = 1)), c(a = 1, b = 2, c = 3))
